"""
Basic field analyzer example

Change the fa_address variable to match your laser probe interface.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

from ardrivers import arfieldprobe

fa_address = 'GPIB0::3::INSTR'

# Create an AR_FieldAnalyzer object and initialize the VISA session
fa = arfieldprobe.AR_FieldAnalyzer()
fa.initialize(fa_address)
print('*IDN:', fa.id_query())
probe_id = fa.query_probe_id()
print('Probe:')
print('Model:', probe_id['model'])
print('Serial Number:', probe_id['serial'])
print('Firmware revision:', probe_id['firmware'])
print('Linearization date:', probe_id['linearization'])

# Configure a measurement
fa.config_time_base(20)
fa.config_units(fa.Units.Vm)
fa.config_trigger_mode(fa.TriggerMode.FREERUN)

# Take a measurement
print('Composite:', fa.read_composite_field())
mma = fa.read_mma()
print('Min:', mma['min'])
print('Max:', mma['max'])
print('Avg:', mma['avg'])


fa.close()
