"""
Basic system controller example

Change the sc_address variable to match your system controller.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

from ardrivers import arsystemcontroller

sc_address = 'GPIB0::1::INSTR'


# Function to query and display the current switch configuration
# Only the first 4 switches are queried, this can be changed based on the
# M number of the system controller that is connected.
def print_config(sc):
    for i in range(1, 5):
        print(f'Switch {i}: Position: {sc.query_switch(i)}')

    for i in range(1, 5):
        print(f'Open Collector {i}: {sc.query_open_collector(i)}')

    print(f'12V Trigger: {sc.query_12v()}')


# Create an AR_SC1000 object and initialize the VISA session
sc = arsystemcontroller.AR_SC1000()
sc.initialize(sc_address)

# The SC1000 needs to have power on sent before setting any switches
sc.power(1)

# Print the current configuration
print_config(sc)

# Set the switches to new positions
print('Setting switches...')
sc.set_switch(1, 1)
sc.set_switch(2, 2)
sc.set_switch(3, 3)
sc.set_switch(4, 4)

# Set the open collectors
print('Setting open collectors...')
sc.set_open_collector(1, 1)
sc.set_open_collector(2, 0)
sc.set_open_collector(3, 1)
sc.set_open_collector(4, 0)

# Print the configuration after switching
print_config(sc)
